/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef CONFIG_H
#define CONFIG_H

#include "mpdsonglist.h"
#include "serverinfo.h"
#include <QFont>
#include <QSettings>

class Config : public QSettings {
	Q_OBJECT
private:
	static Config *m_instance;
	Config();

public:
	static Config *instance();

	// Server settings
	void setAutoconnect(bool);
	void setServers(const ServerInfoList &);
	ServerInfoList servers() const;
	ServerInfo server(const QString & = QString::null) const;
	void setReconnect(bool);
	void setReconnectTime(int);
	void setTimeoutTime(int);
	bool autoconnect() const;
	bool reconnect() const;
	int reconnectTime() const;
	int timeoutTime() const;

	// Look and feel
	void setAlternatingRowColors(bool);
	void setAutoResizeColumns(bool);
	void setEnqueue(bool);
	void setFont(const QFont &);
	void setOpaqueResize(bool);
	void setRecurse(bool);
	void setShowRemaining(bool);
	bool alternatingRowColors() const;
	bool autoResizeColumns() const;
	bool enqueue() const;
	QFont font() const;
	bool opaqueResize() const;
	bool scrollToPlaying() const;
	bool showRemaining() const;
	// Playlist
	void setPlaylistPattern(const QString &);
	void setScrollToPlaying(bool);
	QString playlistPattern() const;
	bool recurse() const;

	// Language
	void setLocale(const QString &);
	void setTranslation(bool);
	QString locale() const;
	bool translation() const;

	// Popups
	void setNotificationsEnabled(bool);
	void setNotificationsPosition(int);
	void setNotificationsTimeout(int);
	bool notificationsEnabled() const;
	int notificationsPosition() const;
	int notificationsTimeout() const;

	// System tray
	void setMinimizeToTray(bool);
	void setStartHidden(bool);
	void setTrayIconEnabled(bool);
	bool minimizeToTray() const;
	bool startHidden() const;
	bool trayIconEnabled() const;

	// Auto player
	void setAutoAddCount(int);
	void setAutoAddPos(int);
	void setAutoAddSongs(bool);
	void setAutoRemoveSongs(bool);
	int autoAddCount() const;
	int autoAddPos() const;
	bool autoAddSongs() const;
	bool autoRemoveSongs() const;

	// Window and splitter sizes
	void setDirectorySplitterSizes(const QByteArray &);
	void setLibraryHSplitterSizes(const QByteArray &);
	void setLibraryVSplitterSizes(const QByteArray &);
	void setMainSplitterSizes(const QByteArray &);
	void setPlaylistsSplitterSizes(const QByteArray &);
	void setWindowSize(const QSize &);
	QByteArray directorySplitterSizes() const;
	QByteArray libraryHSplitterSizes() const;
	QByteArray libraryVSplitterSizes() const;
	QByteArray mainSplitterSizes() const;
	QByteArray playlistsSplitterSizes() const;
	QSize windowSize() const;

	// View's properties
	void setHeaderViewState(const QString &, const QByteArray &);
	QByteArray headerViewState(const QString &) const;

	// Radio stations
	void addRadioStation(const QString &title, const QString &url);
	void removeRadioStations(const MPDSongList &stations);
	MPDSongList radioStations() const;

	// Guesser
	void setGuessPattern(const QString &);
	void setTagGuesserEnabled(bool);
	void setTestFilename(const QString &);
	QString guessPattern() const;
	bool tagGuesserEnabled() const;
	QString testFilename() const;

signals:
	void alternatingChanged(bool);
	void autoResizeChanged(bool);
	void fontChanged(const QFont &);
	void opaqueResizeChanged(bool);
	void serverListChanged(const ServerInfoList &);
	void trayIconChanged(bool);
};

#endif
