/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include "serverinfo.h"
#include "ui_mainwindow.h"
#include "mpdsong.h"
#include "mpdstats.h"

class MainWindow : public QMainWindow, private Ui::MainWindow {
	Q_OBJECT

private:
	class Config *m_config;
	class MPD *m_mpd;
	QFont m_font;
	QLabel *m_statsLabel;
	QList<QAction*> m_actions;
	class QProgressBar *m_progressBar;
	class TrayIcon *m_trayIcon;

public:
	MainWindow();

private slots:
	// Auto connected
	void on_about_triggered();
	void on_splitter_splitterMoved(int, int);
	void on_preferences_triggered();

	// Mine
	void alternatingChanged(bool);
	void closeEvent(QCloseEvent *);
	void connectToMPD();
	void disconnected(const QString &);
	void fontChanged(const QFont &);
	void opaqueResizeChanged(bool);
	void resizeEvent(QResizeEvent *);
	void setSong(const MPDSong &);
	void setStats(const MPDStats &);
	void serverListChanged(const ServerInfoList &);
	void updateStart(int);
	void updateProgress(int);
	void updateDone();

public slots:
	void showHide();
};
#endif
