/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSONG_H
#define MPDSONG_H

#include "libmpdclient.h"
#include <QString>

class MPDSong {
public:
	enum Type { ERROR, SONG, STREAM, PLAYLIST, PLAYLISTSONG, PLAYLISTSTREAM, UNKNOWN };

private:
	class MPDSongPrivate *d;
    friend QDataStream &operator>>(QDataStream &, MPDSong &);
    friend QDataStream &operator<<(QDataStream &, const MPDSong &);
	void parsePlaylist(const QString &);
	void parseSong(mpd_Song *);

public:
	// Create blank song
	MPDSong();
	// Copy constructor
	MPDSong(const MPDSong &);
	// Create song from a mpd_InfoEntity typically song or playlist
	MPDSong(mpd_InfoEntity *);
	// Destructor
	~MPDSong();
	// Create stream song, just url and title
	static MPDSong createStream(const QString &title, const QString &url);
	// Create playlist song, just url
	static MPDSong createPlaylist(const QString &url);
	// This one is for creating dummy songs for pattern testing
	static MPDSong createTest(const QString &url);

	MPDSong::Type type() const;
	bool isNull() const;
	int pos() const;
	int secs() const;
	int id() const;
	void setArtist(const QString &);
	QString artist() const;
	void setAlbum(const QString &);
	QString album() const;
	void setTrack(const QString &);
	QString track() const;
	QString filename() const;
	void setUrl(const QString &);
	QString url() const;
	QString time() const;
	void setTitle(const QString &);
	QString title() const;
	QString date() const;
	QString genre() const;
	QString composer() const;
	bool contains(const QRegExp &) const;
	bool operator<(const MPDSong &other) const;
	bool operator==(const MPDSong &other) const;
	MPDSong &operator=(const MPDSong &);
};

QDataStream &operator<<(QDataStream &, const MPDSong &);
QDataStream &operator>>(QDataStream &, MPDSong &);

#endif
