/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef MPDSONGMODEL_H
#define MPDSONGMODEL_H

#include "headerview.h"
#include "mpdsonglist.h"
#include <QAbstractTableModel>
#include <QRegExp>
#include <QStringList>

class MPDSongModel : public QAbstractTableModel {
protected:
	bool m_dragDisabled;
	HeaderView *m_header;
	MPDSongList m_all, m_visible;
	QRegExp m_albumFilter, m_artistFilter, m_titleFilter;
	QList<HeaderView::Column> m_columns;
	virtual void filter();
	MPDSong song(const QModelIndex &) const;

public:
	MPDSongModel(QObject *);
	MPDSongModel(QObject *, HeaderView *);
	virtual int columnCount(const QModelIndex & = QModelIndex()) const;
	virtual int rowCount(const QModelIndex & = QModelIndex()) const;
	virtual QVariant data(const QModelIndex &, int) const;
	virtual QVariant headerData(int, Qt::Orientation, int = Qt::DisplayRole) const;
	virtual Qt::ItemFlags flags(const QModelIndex &) const;
			
	void setAlbumFilter(const QRegExp &);
	void setArtistFilter(const QRegExp &);
	virtual void setFilter(const QString &);
	void sort(int column, Qt::SortOrder order = Qt::AscendingOrder);

	void setSongs(const MPDSongList &);
	MPDSongList songs() const;
	MPDSongList songs(const QModelIndexList &) const;
	MPDSongList songs(const QModelIndex &) const;
	
	void setDragDisabled(bool);
	bool isDragDisabled() const;
	virtual QStringList mimeTypes() const;
	virtual QMimeData *mimeData(const QModelIndexList &) const;
};
#endif
