/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "mpdstats.h"

class MPDStatsPrivate {
public:
	QAtomic ref;
	int m_numberOfArtists, m_numberOfAlbums, m_numberOfSongs;
	unsigned long m_uptime, m_dbUpdateTime, m_playTime, m_dbPlayTime;
	MPDStatsPrivate() :
			ref(1),
			m_numberOfArtists(0),
			m_numberOfAlbums(0),
			m_numberOfSongs(0),
			m_uptime(0),
			m_dbUpdateTime(0),
			m_playTime(0),
	m_dbPlayTime(0) {}}
;

MPDStats::MPDStats() {
	d = new MPDStatsPrivate();
}

MPDStats::MPDStats(mpd_Stats *s) {
	d = new MPDStatsPrivate();
	d->m_numberOfArtists = s->numberOfArtists;
	d->m_numberOfAlbums = s->numberOfAlbums;
	d->m_numberOfSongs = s->numberOfSongs;
	d->m_uptime = s->uptime;
	d->m_dbUpdateTime = s->dbUpdateTime;
	d->m_playTime = s->playTime;
	d->m_dbPlayTime = s->dbPlayTime;
}

MPDStats::MPDStats(const MPDStats &other) {
	d = other.d;
	d->ref.ref();
}

MPDStats::~MPDStats() {
	if (!d->ref.deref())
		delete d;
}

int MPDStats::numberOfArtists() const {
	return d->m_numberOfArtists;
}
int MPDStats::numberOfAlbums() const {
	return d->m_numberOfAlbums;
}
int MPDStats::numberOfSongs() const {
	return d->m_numberOfSongs;
}
unsigned long MPDStats::uptime() const {
	return d->m_uptime;
}
unsigned long MPDStats::dbUpdateTime() const {
	return d->m_dbUpdateTime;
}
unsigned long MPDStats::playTime() const {
	return d->m_playTime;
}
unsigned long MPDStats::dbPlayTime() const {
	return d->m_dbPlayTime;
}

MPDStats &MPDStats::operator=(const MPDStats &other) {
	qAtomicAssign(d, other.d);
    return *this;
}
