/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "mpdstatus.h"

class MPDStatusPrivate {
public:
	QAtomic ref;
	int m_volume, m_repeat, m_random, m_playlistLength, m_state,
	m_crossfade, m_song, m_songid, m_elapsedTime, m_totalTime,
	m_bitRate, m_bits, m_channels, m_updatingDb;
	long long m_playlist;
	unsigned int m_sampleRate;
	QString m_error;
	MPDStatusPrivate() :
			ref(1),
			m_volume(0),
			m_repeat(0),
			m_random(0),
			m_playlistLength(0),
			m_state(0),
			m_crossfade(0),
			m_song(-1),
			m_songid(-1),
			m_elapsedTime(0),
			m_totalTime(0),
			m_bitRate(0),
			m_bits(0),
			m_channels(0),
			m_updatingDb(0),
			m_playlist(0),
			m_sampleRate(0),
	m_error(QString::null) {}}
;

MPDStatus::MPDStatus() {
	d = new MPDStatusPrivate();
}

MPDStatus::MPDStatus(mpd_Status *s) {
	d = new MPDStatusPrivate();
	d->m_volume = s->volume;
	d->m_repeat = s->repeat;
	d->m_random = s->random;
	d->m_playlistLength = s->playlistLength;
	d->m_state = s->state;
	d->m_crossfade = s->crossfade;
	d->m_song = s->song;
	d->m_songid = s->songid;
	d->m_elapsedTime = s->elapsedTime;
	d->m_totalTime = s->totalTime;
	d->m_bitRate = s->bitRate;
	d->m_bits = s->bits;
	d->m_channels = s->channels;
	d->m_updatingDb = s->updatingDb;
	d->m_playlist = s->playlist;
	d->m_sampleRate = s->sampleRate;
	d->m_error = QString::fromUtf8(s->error);
}

MPDStatus::MPDStatus(const MPDStatus &other) {
	d = other.d;
	d->ref.ref();
}

MPDStatus::~MPDStatus() {
	if (!d->ref.deref())
		delete d;
}

int MPDStatus::MPDStatus::volume() const {
	return d->m_volume;
}

int MPDStatus::repeat() const {
	return d->m_repeat;
}

int MPDStatus::random() const {
	return d->m_random;
}

int MPDStatus::playlistLength() const {
	return d->m_playlistLength;
}

int MPDStatus::state() const {
	return d->m_state;
}

int MPDStatus::crossfade() const {
	return d->m_crossfade;
}

int MPDStatus::song() const {
	return d->m_song;
}

int MPDStatus::songid() const {
	return d->m_songid;
}

int MPDStatus::elapsedTime() const {
	return d->m_elapsedTime;
}

void MPDStatus::setElapsedTime(int time) {
	d->m_elapsedTime = time;
}

int MPDStatus::totalTime() const {
	return d->m_totalTime;
}

int MPDStatus::bitRate() const {
	return d->m_bitRate;
}

int MPDStatus::bits() const {
	return d->m_bits;
}

int MPDStatus::channels() const {
	return d->m_channels;
}

int MPDStatus::updatingDb() const {
	return d->m_updatingDb;
}

long long MPDStatus::playlist() const {
	return d->m_playlist;
}

unsigned int MPDStatus::sampleRate() const {
	return d->m_sampleRate;
}

QString MPDStatus::error() const {
	return d->m_error;
}

MPDStatus &MPDStatus::operator=(const MPDStatus &other) {
	qAtomicAssign(d, other.d);
	return *this;
}
