/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "config.h"
#include "mpd.h"
#include "notifications.h"
#include "passivepopup.h"
#include "richtext.h"
#include <QApplication>
#include <QDesktopWidget>
#include <QPixmap>
#include <QProcess>

class NotifierPrivate {
public:
	virtual void notify(QString) = 0;
};

class CustomNotifier : public NotifierPrivate {
public:
	void notify(QString text) {
		Config *m_config = Config::instance();
		PassivePopup::Position pos = (PassivePopup::Position)m_config->notificationsPosition();
		new PassivePopup("QMPDClient", text, QPixmap(":/icons/qmpdclient22.png"), pos, m_config->notificationsTimeout());
	}
};

Notifications::Notifications(QObject *parent, WId w) : QObject(parent), m_config(Config::instance()) {
	setObjectName("notifications");
	m_notifier = new CustomNotifier();
	connect(MPD::instance(), SIGNAL(playingSongUpdated(MPDSong)), this, SLOT(setSong(MPDSong)));
}

Notifications::~Notifications() {
	delete m_notifier;
}

void Notifications::setSong(const MPDSong &s) {
	if (s.isNull()) {
		m_previousUrl = QString::null;
		return;
	}

	if (m_previousUrl == s.url() || !m_config->notificationsEnabled() || m_config->notificationsTimeout() < 1) {
		m_previousUrl = s.url();
		return;
	}

	int desktopWidth = QApplication::desktop()->width();
	QString title = elideRichText("<b>", s.title(), "</b>", desktopWidth/2) + "<br />";
	QString artist = elideRichText("", s.artist(), "", desktopWidth/4);
	QString album = elideRichText("", s.album(), "", desktopWidth/4);
	title += artist;
	if (!artist.isEmpty() && !album.isEmpty())
		title += " - ";
	if (!album.isEmpty())
		title += album;

	m_notifier->notify(title);
	m_previousUrl = s.url();
}
