/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#ifndef PLAYLISTVIEW3_H
#define PLAYLISTVIEW3_H

#include "mpdsonglist.h"
#include <QListView>
#include <QLine>

class PlaylistView : public QListView {
	Q_OBJECT

private:
	bool m_hidden;
	class Config *m_config;
	class MPD *m_mpd;
	class PlaylistModel *m_model;
	QAction *m_cropAction, *m_informationAction, *m_randomAction, *m_removeAction, *m_repeatAction;
	QLine m_dropLine;
	QMenu *m_menu;

	void contextMenuEvent(QContextMenuEvent *);
	void selectionChanged(const QItemSelection & = QItemSelection(), const QItemSelection & = QItemSelection());
	void mouseMoveEvent(QMouseEvent *);
	void mousePressEvent(QMouseEvent *);
	void mouseReleaseEvent(QMouseEvent *);
	void paintEvent(QPaintEvent *);
	void hideEvent(QHideEvent *);

	bool hasDroppableFormat(const QMimeData *);
	void dragLeaveEvent(QDragLeaveEvent *);
	void dragMoveEvent(QDragMoveEvent *);
	void dropEvent(QDropEvent *);

public:
	PlaylistView(QWidget *);

private slots:
	void indexActivated(const QModelIndex &);
	void information();
	void jumpToSong();
	void setSong(const MPDSong &);
	void setPlaylist(const MPDSongList &);

public slots:
	void cropItems();
	void removeItems();
	void savePlaylist();

signals:
	void toggleActions(bool);
};
#endif
