/*
 * QMPDClient - An MPD client written in Qt 4.
 * Copyright (C) 2005-2006 Hvard Tautra Knutsen <havtknut@tihlde.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

#include "trayicon.h"
#include "mpd.h"
#include "richtext.h"
#include <QApplication>
#include <QDesktopWidget>
#include <QMenu>
#include <QPainter>

TrayIcon::TrayIcon(QWidget *parent) : QSystemTrayIcon(parent), m_mpd(MPD::instance()) {
#ifdef Q_WS_MAC
m_connected = QPixmap(":/icons/qmpdclient128.png");
m_disconnected = QPixmap(":/icons/qmpdclient128d.png");
#endif

#ifdef Q_WS_WIN
	m_connected = QPixmap(16, 16);
#endif
#ifdef Q_WS_X11
	m_connected = QPixmap(22, 22);
#endif
#if defined Q_WS_X11 || defined Q_WS_WIN
	m_connected.fill(parent->palette().brush(QPalette::Window).color());
	QPainter p(&m_connected);
 	p.drawPixmap(0, 0, QPixmap(QString(":/icons/qmpdclient%1.png").arg(m_connected.width())));
	m_disconnected = QPixmap(m_connected.size());
	m_disconnected.fill(parent->palette().brush(QPalette::Window).color());
	QPainter p2(&m_disconnected);
	p2.drawPixmap(0, 0, QPixmap(QString(":/icons/qmpdclient%1d.png").arg(m_connected.width())));
#endif

	setIcon(m_disconnected);

	QMenu *menu = new QMenu(parent);
	menu->addAction(QPixmap(":/icons/next.png"), tr("Next"), m_mpd, SLOT(next()));
	menu->addAction(QPixmap(":/icons/play.png"), tr("Play"), m_mpd, SLOT(play()));
	menu->addAction(QPixmap(":/icons/pause.png"), tr("Pause"), m_mpd, SLOT(pause()));
	menu->addAction(QPixmap(":/icons/stop.png"), tr("Stop"), m_mpd, SLOT(stop()));
	menu->addAction(QPixmap(":/icons/prev.png"), tr("Previuos"), m_mpd, SLOT(prev()));
	menu->addSeparator();
	menu->addAction(QPixmap(":/icons/crystal/exit.png"), tr("Quit"), qApp, SLOT(quit()));
	setContextMenu(menu);

	connect(this, SIGNAL(activated(QSystemTrayIcon::ActivationReason)), this, SLOT(action(QSystemTrayIcon::ActivationReason)));
	connect(m_mpd, SIGNAL(playingSongUpdated(MPDSong)), this, SLOT(setSong(MPDSong)));
	connect(m_mpd, SIGNAL(connected(ServerInfo)), this, SLOT(connected()));
	connect(m_mpd, SIGNAL(disconnected(QString)), this, SLOT(disconnected()));

	m_mpd->isConnected() ? connected() : disconnected();

	setToolTip(NAMEVER);
}

void TrayIcon::action(QSystemTrayIcon::ActivationReason reason) {
	if (reason != QSystemTrayIcon::Context)
		emit clicked();
}

void TrayIcon::setSong(const MPDSong &s) {
	if (s.isNull()) {
		QString tooltip = "<html><body>";
		tooltip += "<table><tr><td><img src=':/icons/qmpdclient16.png'></td><td valign='middle'>";
		tooltip += QString("&nbsp;%1</td></tr></table>").arg(NAMEVER);
		tooltip += QString("<b>%1</b>").arg(tr("Not playing", "This is for the trayicon tooltip, indicating that no song is playing"));
		tooltip += "</body></html>";
		setToolTip(tooltip);
		return;
	}

	// Make nice tooltip
	int desktopWidth = QApplication::desktop()->width();
	QString artist = elideRichText("", s.artist(), "", desktopWidth/8);
	QString album = elideRichText("", s.album(), "", desktopWidth/8);
	QString tooltip = "<html><body>";
	tooltip += "<table><tr><td><img src=':/icons/qmpdclient16.png'></td><td valign='middle'>";
	tooltip += QString("&nbsp;%1</td></tr></table>").arg(NAMEVER);
	tooltip += elideRichText("<b>", s.title(), "</b>", desktopWidth/4) + "<br />";
	if (!artist.isEmpty())
		tooltip += artist;
	if (!artist.isEmpty() && !album.isEmpty())
		tooltip += " - ";
	if (!album.isEmpty())
		tooltip += album;
	tooltip += "</body></html>";
	setToolTip(tooltip);
}

void TrayIcon::connected() {
	setIcon(m_connected);
}

void TrayIcon::disconnected() {
	setIcon(m_disconnected);
}
